@@ -1,12 +1,11 @@
 package CGI::Application::Plugin::ActionDispatch;
 
 use strict;
-use Data::Dumper;
 use Class::Inspector;
 use CGI::Application::Plugin::ActionDispatch::Attributes;
 require Exporter;
 
-our $VERSION = '0.91';
+our $VERSION = '0.93';
 our @ISA = qw(Exporter);
 our @EXPORT = qw(action_args);
 
@@ -147,8 +146,6 @@ sub action_args {
     return;
   }
 
-  print @args, Dumper($self), "\n\n";
-
   return undef unless defined $self->{__CAP_ACTION_ARGS};
   return wantarray ? @{$self->{__CAP_ACTION_ARGS}} : shift @{$self->{__CAP_ACTION_ARGS}};
 }
